@@ -20,7 +20,7 @@ class CurrentUserMiddleware:
             # so no signal handler should be attached
             return
 
-        if hasattr(request, 'user') and request.user.is_authenticated():
+        if hasattr(request, 'user') and request.user.is_authenticated:
             user = request.user
         else:
             user = None
